@@ -6,7 +6,7 @@
 #include "QvernoteWindow.h"
 #include "QvernoteAPI.h"
 
-using namespace qvernote::api;
+
 
 class QDeleteNotebookView : public QvernoteWindow
 {
@@ -17,6 +17,9 @@ public:
     ~QDeleteNotebookView();
 
     void loadNotebooksIntoView();
+    void showEvent(QShowEvent *) {
+    	loadNotebooksIntoView();
+    }
 
 public slots:
 	void setItemMark(QListWidgetItem *item);
