@@ -33,6 +33,7 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 	if(isNewNote)
 	{
 		this->setWindowTitle("Edit note - Untitled");
+		ui.wvNoteEdit->setHtml("<html><head/><body/></html>");
 	}
 	else
 	{
@@ -60,7 +61,10 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 	QObject::connect(ui.wvNoteEdit, SIGNAL(linkClicked(QUrl)), this, SLOT(loadResource(QUrl)));
 
 	if(m_Note.attributes.source != "web.clip")
+	{
 		ui.wvNoteEdit->page()->setContentEditable(true);
+		ui.wvNoteEdit->setTextSizeMultiplier(1.4);
+	}
 
 
 #ifdef Q_WS_MAEMO_5
@@ -242,6 +246,9 @@ void QNoteEditWindow::attachFile()
 			&selectedFilter,
 			options);
 
+	if(fileName.isEmpty())
+		return;
+
 	QFileInfo fi(fileName);
 	QString htmlTag;
 	QString htmlNode;
