@@ -9,25 +9,38 @@
 #include <QGraphicsProxyWidget>
 #include <QGraphicsGridLayout>
 #include "QNoteListItemWidget.h"
-#include "QNoteEditWindow.h"
 #include "QDeleteNotesView.h"
 #include "QNoteViewWindow.h"
+#include "QKeyGrabber.h"
+#include "QNoteListView.h"
+#include "QNoteGridView.h"
 
-using namespace qvernote;
-using namespace qvernote::api;
-
-QNotesView::QNotesView(QvernoteAPI* hEvernote, const Notebook& notebook, QWidget *parent)
-    : QvernoteWindow(parent), m_hEvernote(hEvernote), m_Notebook(notebook)
+QNotesView::QNotesView(const Notebook& notebook, QWidget *parent)
+    : QvernoteWindow(parent), m_hEvernote(QvernoteAPI::Instance()), m_Notebook(notebook), isSearchShown(false), isSynchronizing(false)
 {
 	ui.setupUi(this);
 
 	this->setWindowTitle(QString(notebook.name.c_str()));
-	ui.gridLayout_2->setAlignment(ui.lvNoteList, Qt::AlignTop);
+
+	switch(QvernoteSettings::Instance()->getNotesView()) {
+	case QvernoteSettings::NV_LIST:
+		m_pNoteListViewWidget = new QNoteListView(this);
+		break;
+	case QvernoteSettings::NV_GRID:
+		m_pNoteListViewWidget = new QNoteGridView(m_Notebook.guid, this);
+		break;
+	default:
+		break;
+	}
+
+	ui.gridLayout_2->addWidget(dynamic_cast<QWidget*>(m_pNoteListViewWidget), 1, 0, 1, 2);
+	ui.gridLayout_2->setAlignment(Qt::AlignTop);
+
 
 	QObject::connect(ui.actionReload, SIGNAL(triggered(bool)), this, SLOT(reloadNotes()));
 	QObject::connect(ui.pbNewNote, SIGNAL(clicked()), this, SLOT(openNewNoteWindow()));
 	//QObject::connect(ui.lvNoteList, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(openNoteEditor(QListWidgetItem *)));
-	QObject::connect(ui.lvNoteList, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(openNoteViewer(QListWidgetItem *)));
+	//QObject::connect(ui.lvNoteList, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(openNoteViewer(QListWidgetItem *)));
 
 	QObject::connect(ui.actionDelete_notes, SIGNAL(triggered(bool)), this, SLOT(loadDeleteNotesView()));
 
@@ -36,16 +49,27 @@ QNotesView::QNotesView(QvernoteAPI* hEvernote, const Notebook& notebook, QWidget
 	displayInformationBox("Loading notes. Please wait...");
 }
 
-QNotesView::QNotesView(QvernoteAPI* hEvernote, QString windowTitle, QWidget *parent)
-: QvernoteWindow(parent), m_hEvernote(hEvernote)
+
+QNotesView::QNotesView(QString windowTitle, QWidget *parent)
+: QvernoteWindow(parent), m_hEvernote(QvernoteAPI::Instance()), isSearchShown(false), isSynchronizing(false)
 {
 	ui.setupUi(this);
 
 	this->setWindowTitle(windowTitle);
 	ui.pbNewNote->setVisible(false);
 
-	ui.gridLayout_2->setAlignment(ui.lvNoteList, Qt::AlignTop);
-	QObject::connect(ui.lvNoteList, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(openNoteEditor(QListWidgetItem *)));
+	switch(QvernoteSettings::Instance()->getNotesView()) {
+	case QvernoteSettings::NV_LIST:
+		m_pNoteListViewWidget = new QNoteListView(this);
+		break;
+	case QvernoteSettings::NV_GRID:
+		m_pNoteListViewWidget = new QNoteGridView(m_Notebook.guid, this);
+		break;
+	default:
+		break;
+	}
+
+	ui.gridLayout_2->addWidget(dynamic_cast<QWidget*>(m_pNoteListViewWidget), 1, 0, 1, 2);
 	loadNotesIntoView();
 }
 
@@ -59,46 +83,10 @@ void QNotesView::reloadNotes()
 	m_pBackgroundJob->start();
 }
 
-void QNotesView::loadNotesIntoView()
+void QNotesView::loadNotesIntoView(QString noteFilter)
 {
-	Note note;
-	bool hasMoreNotes = true;
-	//int maxColumns = (int)((int)this->geometry().width() / (int)225) - 1;
-	//int columnCount = 0;
-	//int rowIndex = 0;
-	//int noteCount = 0;
-
-	//qDebug() << "maxColumns" << maxColumns;
-	ui.lvNoteList->clear();
-	ui.lvNoteList->setVisible(false);
-	ui.lvNoteList->setListItemHeight(70);
-
-	for(hasMoreNotes = m_hEvernote->getFirstNote(note); hasMoreNotes; hasMoreNotes = m_hEvernote->getNextNote(note))
-	{
-		//QNoteWidget* w = new QNoteWidget(note, this);
-		//w->setAttribute(Qt::WA_OpaquePaintEvent, true);
-		//m_vNoteWidgets.push_back(w);
-		//QGraphicsProxyWidget* gp = scene.addWidget(w);
-		//gp->setGeometry(QRectF(columnCount*(w->width() + 20), rowIndex*(w->height() + 20), w->width(), w->height()));
-
-		QListWidgetItem* iw = new QListWidgetItem(ui.lvNoteList);
-		iw->setSizeHint(QSize(0, 70));
-		ui.lvNoteList->setItemWidget(iw, new QNoteListItemWidget(note, false, this));
-
-		/*if(columnCount >= maxColumns)
-		{
-			columnCount = 0;
-			rowIndex++;
-		}
-		else
-		{
-			columnCount++;
-		}*/
-
-	}
-
-	ui.lvNoteList->setVisible(true);
-	setProgressIndicator(false);
+	isSynchronizing = true;
+	m_pNoteListViewWidget->redrawNotes(noteFilter);
 }
 
 void QNotesView::openNewNoteWindow()
@@ -110,6 +98,7 @@ void QNotesView::openNewNoteWindow()
 	pNoteEditWindow->show();
 }
 
+/*
 void QNotesView::openNoteEditor(QListWidgetItem *item)
 {
 	QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(item);
@@ -118,6 +107,7 @@ void QNotesView::openNoteEditor(QListWidgetItem *item)
 	//pNoteEditWindow->show();
 	openNoteEditor(w->getNote());
 }
+*/
 /*
 void QNotesView::openNoteEditor(QNoteListItemWidget *item)
 {
@@ -132,39 +122,42 @@ void QNotesView::openNoteEditor(Note& note, QEnmlReader* reader)
 	pNoteEditWindow->show();
 }
 
-void QNotesView::openNoteViewer(QListWidgetItem *item)
+void QNotesView::openNoteViewer(Note& note)
 {
-	QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(item);
-	QNoteViewWindow* pWnd = new QNoteViewWindow(w->getNote(), this);
+	QNoteViewWindow* pWnd = new QNoteViewWindow(note, this);
 	connect(pWnd, SIGNAL(startEditorSignal(Note&, QEnmlReader*)), this, SLOT(openNoteEditor(Note&, QEnmlReader*)));
 	pWnd->show();
 }
 
 void QNotesView::getNextNote(Note& nextNote)
 {
-	QList<QListWidgetItem*> l = ui.lvNoteList->selectedItems();
-	QListWidgetItem* nextItem = ui.lvNoteList->item(ui.lvNoteList->row(l[0]) + 1);
+	//QList<QListWidgetItem*> l = ui.lvNoteList->selectedItems();
+	//QListWidgetItem* nextItem = ui.lvNoteList->item(ui.lvNoteList->row(l[0]) + 1);
 
-	if(nextItem == NULL)
+
+	if(m_pNoteListViewWidget->nextNote(nextNote) == false)
 	{
 		displayInformationBox("This is the last note");
 	}
-	else
+	/*else
 	{
-		QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(nextItem);
-		ui.lvNoteList->setItemSelected(nextItem, true);
-		nextNote = w->getNote();
+		//QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(nextItem);
+		//ui.lvNoteList->setItemSelected(nextItem, true);
+		//nextNote = w->getNote();
 	}
+	*/
 }
 
 void QNotesView::getPrevNote(Note& prevNote)
 {
-	QList<QListWidgetItem*> l = ui.lvNoteList->selectedItems();
+	//QList<QListWidgetItem*> l = ui.lvNoteList->selectedItems();
 
-	if(ui.lvNoteList->row(l[0]) == 0)
+	if(m_pNoteListViewWidget->prevNote(prevNote) == false)
 	{
 		displayInformationBox("This is the first note");
 	}
+
+	/*
 	else
 	{
 		QListWidgetItem* prevItem = ui.lvNoteList->item(ui.lvNoteList->row(l[0]) - 1);
@@ -172,11 +165,12 @@ void QNotesView::getPrevNote(Note& prevNote)
 		QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(prevItem);
 		prevNote = w->getNote();
 	}
+	*/
 }
 
 void QNotesView::loadDeleteNotesView()
 {
-	QDeleteNotesView* p_Wnd = new QDeleteNotesView(m_hEvernote, QString(m_Notebook.name.c_str()), this);
+	QDeleteNotesView* p_Wnd = new QDeleteNotesView(QString(m_Notebook.name.c_str()), this);
 	p_Wnd->show();
 }
 
@@ -188,12 +182,15 @@ void QNotesView::notesViewShutdown()
 
 bool QNotesView::queryNotes()
 {
-	return m_hEvernote->loadNotes(100000, m_Notebook);
+	bool retVal;
+	isSynchronizing = true;
+	retVal =- m_hEvernote->loadNotes(100000, m_Notebook);
+	return retVal;
 }
 
 void QNotesView::clearNote(Note& m_Note)
 {
-	qDebug() << "Delete note content";
+	//qDebug() << "Delete note content";
 
 	m_Note.content.clear();
 	m_Note.content.reserve(0);
@@ -207,3 +204,42 @@ void QNotesView::clearNote(Note& m_Note)
 		(*i).alternateData.body.clear();
 	}
 }
+
+void QNotesView::keyPressEvent(QKeyEvent* event)
+{
+	if(!isSearchShown && !isSynchronizing)
+	{
+		QKeyGrabber* dlg = new QKeyGrabber(event->text(), this);
+		ui.gridLayout->addWidget(dlg, 2, 0);
+		QObject::connect(dlg, SIGNAL(redrawParentContents(QString)), this, SLOT(redrawNoteList(QString)));
+		isSearchShown = true;
+	}
+
+	QvernoteWindow::keyPressEvent(event);
+}
+
+void QNotesView::redrawNoteList(QString searchString)
+{
+	//qDebug() << __FUNCTION__ << searchString;
+	if(searchString.isEmpty())
+		isSearchShown = false;
+
+	loadNotesIntoView(searchString);
+}
+
+void QNotesView::onNoteLoadProgress()
+{
+	ui.scrollArea->ensureVisible(0, ui.scrollAreaWidgetContents->geometry().height() + 100);
+}
+
+void QNotesView::onNoteLoadDone()
+{
+	ui.scrollArea->ensureVisible(0, 0);
+	setProgressIndicator(false);
+	isSynchronizing = false;
+}
+
+void QNotesView::orientationChanged()
+{
+	loadNotesIntoView();
+}
