@@ -26,8 +26,6 @@ using namespace evernote::edam;
 using namespace evernote::limits;
 using namespace boost;
 
-namespace qvernote { namespace api {
-
 #define EDAM_CONSUMER_KEY "sharker76"
 #define EDAM_CONSUMER_SECRET "e2cf4349a6e0b44e"
 #define EVERNOTE_HOST	"www.evernote.com"
@@ -101,10 +99,12 @@ public:
 	bool	getNextNote(Note& note);
 	bool	createNewNote(Note& newNote);
 	bool 	updateExistingNote(Note& existingNote);
-	bool	deleteNote(Note& existingNote);
+	bool	deleteNote(Guid noteGuid);
 	bool 	searchNotes(const string& searchString, int maxResults);
 	bool	searchNoteList(vector<Note>::iterator& pos, Guid noteGuid);
 	bool	expungeNote(const Guid noteGuid);
+	bool 	copyNote(Guid noteGuid, Guid toNotebookGuid);
+	bool 	moveNote(Guid noteGuid, Guid toNotebookGuid);
 	bool	undeleteNote(Note& note);
 	bool 	loadTrashNoteList(vector<Note>& noteList);
 	bool	loadResource(Resource& loadedResource, Guid resourceGuid);
@@ -193,7 +193,7 @@ private:
 
 	shared_ptr<UserStoreClient> m_UserStoreClient;
 	shared_ptr<NoteStoreClient> m_NoteStoreClient;
-	shared_ptr<QvernoteStorage> m_LocalStoreClient;
+	QvernoteStorage* m_LocalStoreClient;
 
 	shared_ptr<AuthenticationResult> m_AuthenticationResult;
 	NoteList	m_NoteList;
@@ -210,5 +210,5 @@ private:
 	SynchronizationThread* syncThread;
 	bool m_bIsOnline;
 };
-}}
+
 #endif /* QVERNOTEAPI_H_ */
