@@ -19,6 +19,8 @@ void QvernoteSettings::Load() {
 	LOAD_VAR(Int(), lastUpdateCount, "qvernote/lastupdatecount", 0);
 	LOAD_VAR(ULongLong(), lastSyncTime, "qvernote/lastsynctime", 0);
 	LOAD_VAR(Bool(), WorkOnline, "qvernote/online", true);
+
+	m_NotesView = (NotesView)settings.value("qvernote/notesview", NV_LIST).toInt();
 }
 
 void QvernoteSettings::Store() {
@@ -31,6 +33,7 @@ void QvernoteSettings::Store() {
 	STORE_VAR("qvernote/lastupdatecount", lastUpdateCount);
 	STORE_VAR("qvernote/lastsynctime", lastSyncTime);
 	STORE_VAR("qvernote/online", WorkOnline);
+	STORE_VAR("qvernote/notesview", NotesView);
 }
 
 
