@@ -32,6 +32,11 @@ public:
 		DO_AUTO
 	};
 
+	enum NotesView {
+		NV_LIST,
+		NV_GRID
+	};
+
 	static QvernoteSettings* Instance()
 	{
 		if(settings == NULL)
@@ -48,6 +53,7 @@ public:
 	CONFIG_VAR(int, lastUpdateCount);
 	CONFIG_VAR(qint64, lastSyncTime)
 	CONFIG_VAR(bool, WorkOnline);
+	CONFIG_VAR(NotesView, NotesView);
 public:
 	void 	Store();
 	void	Load();
