@@ -16,16 +16,18 @@
 #include "QTrashWindow.h"
 
 #include "QSyncProgressWidget.h"
+#include "QKeyGrabber.h"
 
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
+#include "QOptionsDialog.h"
 #endif
 
-using namespace qvernote;
-using namespace qvernote::api;
+
+
 
 QvernoteView::QvernoteView(QWidget *parent)
-    : QvernoteWindow(parent), m_hEvernote(QvernoteAPI::Instance())
+    : QvernoteWindow(parent), m_hEvernote(QvernoteAPI::Instance()), isSearchShown(false), isSynchronizing(false)
 {
 	QvernoteSettings* settings = QvernoteSettings::Instance();
 	ui.setupUi(this);
@@ -45,6 +47,7 @@ QvernoteView::QvernoteView(QWidget *parent)
 		displayInformationBox("Initializing note store. It may take a couple of minutes on first sync. Please wait...");
 	}
 
+	/*
 	ui.actionOnline->setChecked(settings->getWorkOnline());
 
 	QvernoteSettings::DisplayOrientation orientation = settings->getDisplayOrientation();
@@ -63,21 +66,27 @@ QvernoteView::QvernoteView(QWidget *parent)
 	actDoAuto->setChecked(orientation == QvernoteSettings::DO_AUTO);
 
 	ui.menubar->addActions(displaySetupGroup->actions());
-
+	*/
 	QObject::connect(ui.lvNotebookList, SIGNAL(itemClicked(QListWidgetItem *)),  this, SLOT(loadNotebook(QListWidgetItem* )));
 	QObject::connect(ui.pbNewNotebook, SIGNAL(clicked()), this, SLOT(createNewNotebook()));
 	QObject::connect(ui.pbSync, SIGNAL(clicked()), this, SLOT(/*synchronizeNoteStore()*/initView()));
+
+	/*
 	QObject::connect(ui.actionUse_SSL, SIGNAL(toggled(bool)), this, SLOT(configureSslProtocol(bool)));
 	QObject::connect(ui.actionOnline, SIGNAL(toggled(bool)), this, SLOT(configureOnlineMode(bool)));
 	QObject::connect(ui.actionAccount, SIGNAL(triggered(bool)), this, SLOT(accountConfig()));
+	*/
 	QObject::connect(ui.actionSearch, SIGNAL(triggered(bool)), this, SLOT(openSearchDialog()));
 	QObject::connect(ui.actionDelete, SIGNAL(triggered(bool)), this, SLOT(openDeleteNotebookWindow()));
 	QObject::connect(ui.actionAbout, SIGNAL(triggered(bool)), this, SLOT(openAboutDialog()));
 	QObject::connect(ui.actionTrash, SIGNAL(triggered(bool)), this, SLOT(openTrashWindow()));
+	QObject::connect(ui.actionOptions, SIGNAL(triggered(bool)), this, SLOT(openOptionsDialog()));
 
+	/*
 	QObject::connect(actDoPortrait, SIGNAL(toggled(bool)), this, SLOT(setPortraitOrientation(bool)));
 	QObject::connect(actDoLandscape, SIGNAL(toggled(bool)), this, SLOT(setLandscapeOrientation(bool)));
 	QObject::connect(actDoAuto, SIGNAL(toggled(bool)), this, SLOT(setAutoOrientation(bool)));
+	*/
 
 	QObject::connect(m_hEvernote, SIGNAL(noteUpdated(QString)), this, SLOT(showSyncProgressInfo(QString)));
 	QObject::connect(this, SIGNAL(progressDataUpdated(QString)), &syncWidget, SLOT(updateProgressData(QString)));
@@ -104,7 +113,7 @@ void QvernoteView::initView()
 	*/
 }
 
-void QvernoteView::loadNotebookList()
+void QvernoteView::loadNotebookList(QString notebookFilter)
 {
 	Notebook notebook;
 	bool hasNextNotebook = false;
@@ -118,12 +127,14 @@ void QvernoteView::loadNotebookList()
 
 	for(hasNextNotebook = m_hEvernote->getFirstNotebook(notebook); hasNextNotebook; hasNextNotebook = m_hEvernote->getNextNotebook(notebook))
 	{
-		//Notebook* newNotebook = new Notebook(notebook);
-		QListWidgetItem* iw = new QListWidgetItem(ui.lvNotebookList);
-		iw->setSizeHint(QSize(0, 70));
-		noteCount += m_hEvernote->getNotebookContentsCount(notebook);
-		ui.lvNotebookList->setItemWidget(iw, new QNotebookListItemWidget(notebook, m_hEvernote, -1, false, ui.lvNotebookList));
-
+		if(QString::fromStdString(notebook.name).startsWith(notebookFilter, Qt::CaseInsensitive))
+		{
+			//Notebook* newNotebook = new Notebook(notebook);
+			QListWidgetItem* iw = new QListWidgetItem(ui.lvNotebookList);
+			iw->setSizeHint(QSize(0, 70));
+			noteCount += m_hEvernote->getNotebookContentsCount(notebook);
+			ui.lvNotebookList->setItemWidget(iw, new QNotebookListItemWidget(notebook, m_hEvernote, -1, false, ui.lvNotebookList));
+		}
 	}
 
 	/* Add special "ALL" notebook */
@@ -148,7 +159,7 @@ void QvernoteView::loadNotebook(QListWidgetItem* p_notebookListItem)
 	QNotebookListItemWidget* p = (QNotebookListItemWidget*)p_notebookListItem->listWidget()->itemWidget(p_notebookListItem);
 	qDebug() << "Loading notebook " << p->getNotebook().name.c_str();
 
-	m_pNotesView = new QNotesView(m_hEvernote, p->getNotebook(), this);
+	m_pNotesView = new QNotesView(p->getNotebook(), this);
 	m_pNotesView->show();
 }
 
@@ -191,70 +202,10 @@ void QvernoteView::deleteSelectedNotebook(QNotebookListItemWidget* notebookWidge
 	}
 }
 
-void QvernoteView::configureSslProtocol(bool checked)
-{
-	QvernoteSettings::Instance()->setUseSsl(checked);
-	setProgressIndicator(true);
-	if(m_hEvernote->reinitNoteStore() == false)
-	{
-		displayError("Failed to configure SSL", QString::fromStdString(m_hEvernote->getLastErrorString()));
-		setProgressIndicator(false);
-	}
-	else
-	{
-		reloadNotebookList();
-	}
-}
-
-void QvernoteView::configureOnlineMode(bool checked)
-{
-	if(m_hEvernote->setOnline(checked) == false)
-	{
-		displayError(QString("Failed to go %1").arg((checked)? "online" : "offline"), QString::fromStdString(m_hEvernote->getLastErrorString()));
-	}
-	else
-	{
-		displayInformationBox(QString("Working %1").arg((checked)? "online" : "offline"));
-		QvernoteSettings::Instance()->setWorkOnline(checked);
-
-		if(m_hEvernote->isOnline())
-			//synchronizeNoteStore();
-			initView();
-	}
-}
-
-void QvernoteView::accountConfig()
-{
-	QvernoteLoginDialog ld;
-	QvernoteSettings* settings = QvernoteSettings::Instance();
-
-	if(ld.exec() == QDialog::Rejected)
-		return;
-
-	while(true)
-	{
-		if(m_hEvernote->Authenticate(
-							settings->getUsername().toStdString(),
-							settings->getPassword().toStdString()))
-		{
-			break;;
-		}
-
-		if(ld.exec() == QDialog::Rejected)
-			return;
-
-	}
-
-	if(m_hEvernote->initNoteStore() == true)
-	{
-		reloadNotebookList();
-	}
-}
-
 void QvernoteView::openSearchDialog()
 {
-	QNoteSearchDialog* pDlg = new QNoteSearchDialog(this);
-	pDlg->show();
+	QNoteSearchDialog pDlg(this);
+	pDlg.exec();
 }
 
 void QvernoteView::searchNote(QString searchString)
@@ -270,7 +221,7 @@ void QvernoteView::searchNote(QString searchString)
 
 	setProgressIndicator(false);
 
-	m_pNotesView = new QNotesView(m_hEvernote, "Search results for " + searchString, this);
+	m_pNotesView = new QNotesView("Search results for " + searchString, this);
 	m_pNotesView->show();
 }
 
@@ -292,11 +243,12 @@ void QvernoteView::orientationChanged()
 
 bool QvernoteView::backgroundInit()
 {
+	isSynchronizing = true;
 	if(m_hEvernote->isOnline())
 		m_hEvernote->synchronizeLocalStorage();
 
 	m_hEvernote->loadNotebookList();
-
+	isSynchronizing = false;
 	return true;
 }
 
@@ -323,3 +275,41 @@ void QvernoteView::showSyncProgressInfo(QString info)
 	//displayInformationBox(info);
 	emit progressDataUpdated(info);
 }
+
+void QvernoteView::openOptionsDialog()
+{
+#ifdef Q_WS_MAEMO_5
+	QOptionsDialog pDlg(this);
+	pDlg.exec();
+#else
+	displayError("Cannot open options", "Maemo5 specific code");
+#endif
+}
+
+void QvernoteView::keyPressEvent(QKeyEvent* event)
+{
+	if(!isSearchShown && !isSynchronizing)
+	{
+		QKeyGrabber* dlg = new QKeyGrabber(event->text(), this);
+		ui.gridLayout->addWidget(dlg, 2, 0);
+		QObject::connect(dlg, SIGNAL(redrawParentContents(QString)), this, SLOT(redrawNotebookList(QString)));
+		isSearchShown = true;
+	}
+
+	QvernoteWindow::keyPressEvent(event);
+}
+
+void QvernoteView::redrawNotebookList(QString searchString)
+{
+	//qDebug() << __FUNCTION__ << searchString;
+	if(searchString.isEmpty())
+		isSearchShown = false;
+
+	loadNotebookList(searchString);
+}
+
+void QvernoteView::clearNotebookList()
+{
+	ui.lvNotebookList->clear();
+	m_hEvernote->loadNotebookList();
+}
