@@ -10,7 +10,7 @@
 #include "QSyncProgressDialog.h"
 #include "QSyncProgressWidget.h"
 
-using namespace qvernote::api;
+
 
 class QvernoteView : public QvernoteWindow
 {
@@ -20,28 +20,25 @@ public:
     QvernoteView(QWidget *parent = 0);
     ~QvernoteView();
 
+    void keyPressEvent(QKeyEvent* event);
+
 public slots:
 	void initView();
 	void loadNotebook(QListWidgetItem* p_notebookListItem);
     void createNewNotebook();
     void synchronizeNoteStore();
     void reloadNotebookList();
-    void loadNotebookList();
+    void loadNotebookList(QString notebookFilter = "");
     void deleteSelectedNotebook(QNotebookListItemWidget*);
-    void configureSslProtocol(bool checked);
-    void configureOnlineMode(bool checked);
-    void accountConfig();
     void openSearchDialog();
     void searchNote(QString searchString);
     void openDeleteNotebookWindow();
     void openAboutDialog();
     void openTrashWindow();
-
+    void openOptionsDialog();
+    void redrawNotebookList(QString searchString);
     void showSyncProgressInfo(QString);
-
-    void setPortraitOrientation(bool) { setDisplayOrientation(QvernoteSettings::DO_PORTRAIT); }
-    void setLandscapeOrientation(bool) { setDisplayOrientation(QvernoteSettings::DO_LANDSCAPE); }
-    void setAutoOrientation(bool) { setDisplayOrientation(QvernoteSettings::DO_AUTO); }
+    void clearNotebookList();
 
     void orientationChanged();
     bool backgroundJobCallback() { return backgroundInit(); }
@@ -60,6 +57,8 @@ private:
     QNotesView*		m_pNotesView;
     QSyncProgressDialog syncDlg;
     QSyncProgressWidget syncWidget;
+    bool	isSearchShown;
+    bool 	isSynchronizing;
 };
 
 #endif // QvernoteView_H
